==> developer-center-api-3.6.3-20210415.114347-7-sources.jar: cn/com/duiba/developer/center/api/domain/dto/authority/BusinessWhiteListDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.authority;

import java.io.Serializable;
import java.util.Date;

/**
* 业务黑白名单表
*/
public class BusinessWhiteListDto implements Serializable {

    private static final long serialVersionUID = -4692779600112499192L;
    /**
    * 业务名称
    */
    private String bizName;

    /**
    * 1 白名单 2 黑名单
    */
    private Integer bizType;


    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    /**
    * 主键
    */
    private Long id;

    /**
    * 0  关  1  开
    */
    private Integer openStatus;

    /**
    * 业务唯一编码
    */
    private String uniqueCode;

    /**
     * 创建人id
     */
    private Long createAdmin;

    /**
     * 修改人id
     */
    private Long modifyAdmin;


    public Long getCreateAdmin() {
        return createAdmin;
    }

    public void setCreateAdmin(Long createAdmin) {
        this.createAdmin = createAdmin;
    }

    public Long getModifyAdmin() {
        return modifyAdmin;
    }

    public void setModifyAdmin(Long modifyAdmin) {
        this.modifyAdmin = modifyAdmin;
    }

    public void setBizName(String bizName) {
        this.bizName = bizName;
    }

    public String getBizName() {
        return bizName;
    }

    public void setBizType(Integer bizType) {
        this.bizType = bizType;
    }

    public Integer getBizType() {
        return bizType;
    }



    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOpenStatus(Integer openStatus) {
        this.openStatus = openStatus;
    }

    public Integer getOpenStatus() {
        return openStatus;
    }

    public void setUniqueCode(String uniqueCode) {
        this.uniqueCode = uniqueCode;
    }

    public String getUniqueCode() {
        return uniqueCode;
    }

}

==> developer-center-api-3.9.42-sources.jar: cn/com/duiba/developer/center/api/domain/dto/authority/BusinessWhiteListDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.authority;

import java.io.Serializable;
import java.util.Date;

/**
* 业务黑白名单表
*/
public class BusinessWhiteListDto implements Serializable {

    private static final long serialVersionUID = -4692779600112499192L;
    /**
    * 业务名称
    */
    private String bizName;

    /**
    * 1 白名单 2 黑名单
    */
    private Integer bizType;


    /**
     * 白名单描述
     */
    private String description;


    /**
    * 创建时间
    */
    private Date gmtCreate;

    /**
    * 修改时间
    */
    private Date gmtModified;

    /**
    * 主键
    */
    private Long id;

    /**
    * 0  关  1  开
    */
    private Integer openStatus;

    /**
    * 业务唯一编码
    */
    private String uniqueCode;

    /**
     * 创建人id
     */
    private Long createAdmin;

    /**
     * 修改人id
     */
    private Long modifyAdmin;


    public Long getCreateAdmin() {
        return createAdmin;
    }

    public void setCreateAdmin(Long createAdmin) {
        this.createAdmin = createAdmin;
    }

    public Long getModifyAdmin() {
        return modifyAdmin;
    }

    public void setModifyAdmin(Long modifyAdmin) {
        this.modifyAdmin = modifyAdmin;
    }

    public void setBizName(String bizName) {
        this.bizName = bizName;
    }

    public String getBizName() {
        return bizName;
    }

    public void setBizType(Integer bizType) {
        this.bizType = bizType;
    }

    public Integer getBizType() {
        return bizType;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getId() {
        return id;
    }

    public void setOpenStatus(Integer openStatus) {
        this.openStatus = openStatus;
    }

    public Integer getOpenStatus() {
        return openStatus;
    }

    public void setUniqueCode(String uniqueCode) {
        this.uniqueCode = uniqueCode;
    }

    public String getUniqueCode() {
        return uniqueCode;
    }

}
